@@ -522,6 +522,9 @@ module.exports = {
 	"8.3.2": "80.0.3987.165",
 	"8.3.3": "80.0.3987.165",
 	"8.3.4": "80.0.3987.165",
+	"8.4.0": "80.0.3987.165",
+	"8.4.1": "80.0.3987.165",
+	"8.5.0": "80.0.3987.165",
 	"9.0.0-beta.1": "82.0.4048.0",
 	"9.0.0-beta.2": "82.0.4048.0",
 	"9.0.0-beta.3": "82.0.4048.0",
@@ -587,10 +590,28 @@ module.exports = {
 	"9.0.3": "83.0.4103.100",
 	"9.0.4": "83.0.4103.104",
 	"9.0.5": "83.0.4103.119",
+	"9.1.0": "83.0.4103.122",
+	"9.1.1": "83.0.4103.122",
+	"9.1.2": "83.0.4103.122",
+	"9.2.0": "83.0.4103.122",
+	"9.2.1": "83.0.4103.122",
 	"10.0.0-beta.1": "84.0.4129.0",
 	"10.0.0-beta.2": "84.0.4129.0",
 	"10.0.0-beta.3": "85.0.4161.2",
 	"10.0.0-beta.4": "85.0.4161.2",
+	"10.0.0-beta.8": "85.0.4181.1",
+	"10.0.0-beta.9": "85.0.4181.1",
+	"10.0.0-beta.10": "85.0.4183.19",
+	"10.0.0-beta.11": "85.0.4183.20",
+	"10.0.0-beta.12": "85.0.4183.26",
+	"10.0.0-beta.13": "85.0.4183.39",
+	"10.0.0-beta.14": "85.0.4183.39",
+	"10.0.0-beta.15": "85.0.4183.39",
+	"10.0.0-beta.17": "85.0.4183.39",
+	"10.0.0-beta.19": "85.0.4183.39",
+	"10.0.0-beta.20": "85.0.4183.39",
+	"10.0.0-beta.21": "85.0.4183.39",
+	"10.0.0-beta.23": "85.0.4183.70",
 	"10.0.0-nightly.20200209": "82.0.4050.0",
 	"10.0.0-nightly.20200210": "82.0.4050.0",
 	"10.0.0-nightly.20200211": "82.0.4050.0",
@@ -665,5 +686,25 @@ module.exports = {
 	"11.0.0-nightly.20200617": "85.0.4162.0",
 	"11.0.0-nightly.20200618": "85.0.4162.0",
 	"11.0.0-nightly.20200619": "85.0.4162.0",
-	"11.0.0-nightly.20200701": "85.0.4179.0"
+	"11.0.0-nightly.20200701": "85.0.4179.0",
+	"11.0.0-nightly.20200702": "85.0.4179.0",
+	"11.0.0-nightly.20200703": "85.0.4179.0",
+	"11.0.0-nightly.20200706": "85.0.4179.0",
+	"11.0.0-nightly.20200707": "85.0.4179.0",
+	"11.0.0-nightly.20200708": "85.0.4179.0",
+	"11.0.0-nightly.20200709": "85.0.4179.0",
+	"11.0.0-nightly.20200716": "86.0.4203.0",
+	"11.0.0-nightly.20200717": "86.0.4203.0",
+	"11.0.0-nightly.20200720": "86.0.4203.0",
+	"11.0.0-nightly.20200721": "86.0.4203.0",
+	"11.0.0-nightly.20200723": "86.0.4209.0",
+	"11.0.0-nightly.20200724": "86.0.4209.0",
+	"11.0.0-nightly.20200729": "86.0.4209.0",
+	"11.0.0-nightly.20200730": "86.0.4209.0",
+	"11.0.0-nightly.20200731": "86.0.4209.0",
+	"11.0.0-nightly.20200803": "86.0.4209.0",
+	"11.0.0-nightly.20200804": "86.0.4209.0",
+	"11.0.0-nightly.20200805": "86.0.4209.0",
+	"11.0.0-nightly.20200811": "86.0.4209.0",
+	"11.0.0-nightly.20200812": "86.0.4209.0"
 };
\ No newline at end of file
